@@ -8,6 +8,15 @@ from holmes.facters import Facter
 
 class RobotsFacter(Facter):
 
+    @classmethod
+    def get_fact_definitions(cls):
+        return {
+            'robots.url': {
+                'title': 'Robots file URL',
+                'description': lambda value: value
+            }
+        }
+
     def get_facts(self):
         if not self.reviewer.is_root():
             return
@@ -16,16 +25,16 @@ class RobotsFacter(Facter):
 
         self.review.data['robots.response'] = None
 
-        self.add_fact(
-            key='robots.url',
-            value=url,
-            title='Robots',
-            unit='robots'
-        )
-
         self.async_get(url, self.handle_robots_loaded)
 
     def handle_robots_loaded(self, url, response):
         logging.debug('Got response (%s) from %s!' % (response.status_code,
                                                       url))
+
+        if url == self.rebase('/robots.txt') and response.status_code <= 399:
+            self.add_fact(
+                key='robots.url',
+                value=url
+            )
+
         self.review.data['robots.response'] = response
